@@ -2,8 +2,4 @@ from mltrace.entities.component import Component
 from mltrace.entities.component_run import ComponentRun
 from mltrace.entities.io_pointer import IOPointer
 
-__all__ = [
-    "Component",
-    "ComponentRun",
-    "IOPointer"
-]
+__all__ = ["Component", "ComponentRun", "IOPointer"]
